<?php

namespace Drupal\editoria11y\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class Editoria11ySettings.
 */
class Editoria11ySettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'editoria11y_form_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'editoria11y.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('editoria11y.settings');
    $form['ignore_containers'] = [
      '#title' => $this->t("Ignore these containers"),
      '#type' => 'textarea',
      '#description' => $this->t('Gets rid of false positives or conflicts with dynamic or "known-good" components.<br>Provide a comma-separated list of jQuery selectors for elements to ignore, e.g.: <code>.my-embedded-feed, #my-social-link-block</code>'),
      '#default_value' => $config->get('ignore_containers'),
    ];
    $form['embedded_content_warning'] = [
      '#title' => $this->t("Warn in Full Check on these elements"),
      '#type' => 'textarea',
      '#description' => $this->t('Some components, like embedded social media feeds, are skipped. Flag them here and a manual Full Check will alert users to the need to check their content manually.<br>Provide a comma-separated list of jQuery selectors for elements to ignore, e.g.: <code>.my-embedded-feed, #my-social-link-block</code>'),
      '#default_value' => $config->get('embedded_content_warning'),
    ];
    $form['no_load'] = [
      '#title' => $this->t("Don't run if these elements are on the page"),
      '#type' => 'textarea',
      '#description' => $this->t('Blocks scanning the currently displayed content, e.g. while inline editing tools are open.<br>Provide a comma-separated list of jQuery selectors, e.g.: <code>#my-inline-page-editor-form, .my-content-type-with-no-editable-content</code>.'),
      '#default_value' => $config->get('no_load'),
    ];
    $form['content_root'] = [
      '#title' => $this->t("Custom content root(s)"),
      '#type' => 'textarea',
      '#description' => $this->t('Defaults to the <code>&lt;main&gt;</code> element. Note that order matters in this list, as the heading order (page outline) tests will follow this order.<br>Set a custom container (or set of containers) as a comma-separated list of jQuery selectors, e.g.: <code>main, #footer</code>'),
      '#default_value' => $config->get('content_root'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('editoria11y.settings')
      ->set('ignore_containers', $form_state->getValue('ignore_containers'))
      ->set('no_load', $form_state->getValue('no_load'))
      ->set('content_root', $form_state->getValue('content_root'))
      ->set('embedded_content_warning', $form_state->getValue('embedded_content_warning'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
